@@ -643,7 +643,7 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             )
         self.deferrable = deferrable
         self.serialized_model: dict
-        self.serialized_tranform: dict
+        self.serialized_transform: dict
 
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
@@ -716,10 +716,10 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             )
 
         self.serialized_model = serialize(self.hook.describe_model(transform_config["ModelName"]))
-        self.serialized_tranform = serialize(
+        self.serialized_transform = serialize(
             self.hook.describe_transform_job(transform_config["TransformJobName"])
         )
-        return {"Model": self.serialized_model, "Transform": self.serialized_tranform}
+        return {"Model": self.serialized_model, "Transform": self.serialized_transform}
 
     def execute_complete(self, context, event=None):
         if event["status"] != "success":
@@ -728,10 +728,10 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             self.log.info(event["message"])
         transform_config = self.config.get("Transform", self.config)
         self.serialized_model = serialize(self.hook.describe_model(transform_config["ModelName"]))
-        self.serialized_tranform = serialize(
+        self.serialized_transform = serialize(
             self.hook.describe_transform_job(transform_config["TransformJobName"])
         )
-        return {"Model": self.serialized_model, "Transform": self.serialized_tranform}
+        return {"Model": self.serialized_model, "Transform": self.serialized_transform}
 
     def get_openlineage_facets_on_complete(self, task_instance) -> OperatorLineage:
         """Return OpenLineage data gathered from SageMaker's API response saved by transform job."""
@@ -747,10 +747,10 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
             self.log.error("Cannot find Model Package Name.", exc_info=True)
 
         try:
-            transform_input = self.serialized_tranform["TransformInput"]["DataSource"]["S3DataSource"][
+            transform_input = self.serialized_transform["TransformInput"]["DataSource"]["S3DataSource"][
                 "S3Uri"
             ]
-            transform_output = self.serialized_tranform["TransformOutput"]["S3OutputPath"]
+            transform_output = self.serialized_transform["TransformOutput"]["S3OutputPath"]
         except KeyError:
             self.log.error("Cannot find some required input/output details.", exc_info=True)
 
@@ -1621,7 +1621,6 @@ class SageMakerCreateNotebookOperator(BaseOperator):
         return SageMakerHook(aws_conn_id=self.aws_conn_id)
 
     def execute(self, context: Context):
-
         create_notebook_instance_kwargs = {
             "NotebookInstanceName": self.instance_name,
             "InstanceType": self.instance_type,
