@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Airflow module for email backend using AWS SES"""
+"""Airflow module for email backend using AWS SES."""
 from __future__ import annotations
 
 from typing import Any
@@ -30,9 +30,9 @@ def send_email(
     files: list | None = None,
     cc: list[str] | str | None = None,
     bcc: list[str] | str | None = None,
-    mime_subtype: str = 'mixed',
-    mime_charset: str = 'utf-8',
-    conn_id: str = 'aws_default',
+    mime_subtype: str = "mixed",
+    mime_charset: str = "utf-8",
+    conn_id: str = "aws_default",
     from_email: str | None = None,
     custom_headers: dict[str, Any] | None = None,
     **kwargs,
